@@ -47,7 +47,7 @@ setMethodS3("getBaseline", "ChipEffectSet", function(this, force=FALSE, verbose=
   paths <- c(path);
 
   # Drop tags from root path?
-  if (getOption(aromaSettings, "devel/dropRootPathTags", FALSE)) {
+  if (getOption(aromaSettings, "devel/dropRootPathTags", TRUE)) {
     path <- dropRootPathTags(path, depth=2, verbose=less(verbose, 5));
     paths <- c(paths, path);
     paths <- unique(paths);
