@@ -258,7 +258,7 @@ setMethodS3("extractTheta", "DChipDcpSet", function(this, units=NULL, ..., drop=
   nbrOfArrays <- length(this);
   gcCount <- 0;
   for (kk in seq_len(nbrOfArrays)) {
-    df <- getFile(this, kk);
+    df <- this[[kk]];
     verbose && enter(verbose, sprintf("Array #%d ('%s') of %d", kk, getName(df), nbrOfArrays));
 
     dataKK <- extractTheta(df, units=units, ..., verbose=less(verbose, 5));
