@@ -367,7 +367,7 @@ setMethodS3("process", "GcContentNormalization", function(this, ..., force=FALSE
   nbrOfArrays <- length(ces);
   res <- vector("list", nbrOfArrays);
   for (kk in seq_len(nbrOfArrays)) {
-    ce <- getFile(ces, kk);
+    ce <- ces[[kk]];
     verbose && enter(verbose, sprintf("Array #%d of %d ('%s')",
                                             kk, nbrOfArrays, getName(ce)));
 
@@ -429,7 +429,7 @@ setMethodS3("process", "GcContentNormalization", function(this, ..., force=FALSE
     # Extract the values to fit the normalization function
     verbose && enter(verbose, "Normalizing log2 signals");
     y <- log2(data[,"theta"]);
-    y <- normalizeFragmentLength(y, fragmentLengths=gcContents,
+    y <- .normalizeFragmentLength(y, fragmentLengths=gcContents,
                              targetFcn=targetFcn, subsetToFit=subset, ...);
     y <- 2^y;
     verbose && exit(verbose);
