@@ -69,7 +69,7 @@ setMethodS3("getFitUnitFunction", "SingleArrayUnitModel", function(this, ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (this$probeModel == "pm-mm") {
     fitUnit <- function(unit, ...) {
-      base::lapply(unit, FUN=function(group) {
+      lapply(unit, FUN=function(group) {
         y <- .subset2(group, 1); # Get intensities
         y <- y[1,] - y[2,];  # PM-MM
         fitfcn(y);
@@ -77,7 +77,7 @@ setMethodS3("getFitUnitFunction", "SingleArrayUnitModel", function(this, ...) {
     }
   } else if (this$probeModel == "min1(pm-mm)") {
     fitUnit <- function(unit, ...) {
-      base::lapply(unit, FUN=function(group) {
+      lapply(unit, FUN=function(group) {
         y <- .subset2(group, 1); # Get intensities
         y <- y[1,] - y[2,];  # PM-MM
         y[y < 1] <- 1;       # min1(PM-MM)=min(PM-MM,1)
@@ -86,7 +86,7 @@ setMethodS3("getFitUnitFunction", "SingleArrayUnitModel", function(this, ...) {
     }
   } else if (this$probeModel == "pm+mm") {
     fitUnit <- function(unit, ...) {
-      base::lapply(unit, FUN=function(group) {
+      lapply(unit, FUN=function(group) {
         y <- .subset2(group, 1); # Get intensities
         y <- y[1,] + y[2,];  # PM+MM
         fitfcn(y);
@@ -94,7 +94,7 @@ setMethodS3("getFitUnitFunction", "SingleArrayUnitModel", function(this, ...) {
     }
   } else {
     fitUnit <- function(unit, ...) {
-      base::lapply(unit, FUN=function(group) {
+      lapply(unit, FUN=function(group) {
         if (length(group) > 0) {
           y <- .subset2(group, 1); # Get intensities
         } else {
@@ -162,7 +162,7 @@ setMethodS3("readUnits", "SingleArrayUnitModel", function(this, array, units=NUL
 
 
   verbose && enter(verbose, "Reading probe intensities from array #", array);
-  df <- getFile(ds, array);
+  df <- ds[[array]];
   verbose && print(verbose, df);
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
