@@ -46,6 +46,10 @@ setMethodS3("getParameters", "SnpPlm", function(this, ...) {
 
 
 setMethodS3("getCellIndices", "SnpPlm", function(this, ..., verbose=FALSE) {
+  requireNamespace("affxparser") || throw("Package not loaded: affxparser")
+  cdfMergeStrands <- affxparser::cdfMergeStrands
+
+
   # Argument 'verbose':
   verbose <- Arguments$getVerbose(verbose);
 
@@ -57,7 +61,7 @@ setMethodS3("getCellIndices", "SnpPlm", function(this, ..., verbose=FALSE) {
   # Merge strands?
   if (this$mergeStrands) {
     verbose && enter(verbose, "Merging strands");
-    cells <- applyCdfGroups(cells, cdfMergeStrands);
+    cells <- .applyCdfGroups(cells, cdfMergeStrands);
     verbose && exit(verbose);
   }
 
