@@ -331,7 +331,7 @@ setMethodS3("process", "UnitTypeScaleNormalization", function(this, ..., skip=FA
   verbose && enter(verbose, "Normalizing ", length(dataSet), " arrays");
   for (kk in seq_along(dataSet)) {
     verbose && enter(verbose, "Array #", kk);
-    df <- getFile(dataSet, kk);
+    df <- dataSet[[kk]];
     verbose && print(verbose, df);
 
     filename <- basename(getPathname(df));
