@@ -44,9 +44,9 @@ setFullNamesTranslator(dsN, df);
 sampleNames <- unique(getNames(dsN));
 
 dsList <- lapply(sampleNames, FUN=function(sampleName) {
-  ds <- extract(dsN, sampleName);
+  ds <- dsN[sampleName];
   lapply(c(T="T", N="N"), FUN=function(type) {
-    extract(ds, sapply(ds, hasTag, type));
+    ds[sapply(ds, hasTag, type)];
   });
 });
 names(dsList) <- sampleNames;
@@ -55,9 +55,9 @@ names(dsList) <- sampleNames;
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Extract (single) tumor-normal pairs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-dfTList <- lapply(dsList, FUN=function(dsList) { getFile(dsList$T, 1) });
+dfTList <- lapply(dsList, FUN=function(dsList) { dsList$T[[1]] });
 dsT <- newInstance(dsList[[1]]$T, dfTList);
-dfNList <- lapply(dsList, FUN=function(dsList) { getFile(dsList$N, 1) });
+dfNList <- lapply(dsList, FUN=function(dsList) { dsList$N[[1]] });
 dsN <- newInstance(dsList[[1]]$T, dfNList);
 
 
@@ -89,7 +89,7 @@ print(scs);
 setOption("PSCBS::reports/pscnSegmentationTransitions", TRUE);
 
 # Generate report for first tumor-normal pair
-df <- getFile(scs, 1);
+df <- scs[[1]];
 fit <- loadObject(df);
 pathname <- report(fit, studyName=getFullName(dsT), verbose=verbose);
 print(pathname);
