@@ -1,18 +1,17 @@
 library("aroma.affymetrix");
-log <- Arguments$getVerbose(-50, timestamp=TRUE);
+verbose <- Arguments$getVerbose(-50, timestamp=TRUE);
 
 
-dataSetName <- "Affymetrix_2009-CytoSampleData";
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# Setup
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+dataSet <- "Affymetrix-CytoSampleData";
 chipType <- "Cytogenetics_Array";
 
-
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Setting up CEL set and locating the CDF file
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 cdf <- AffymetrixCdfFile$byChipType(chipType);
 print(cdf);
 
-csR <- AffymetrixCelSet$byName(dataSetName, cdf=cdf, verbose=log);
+csR <- AffymetrixCelSet$byName(dataSet, cdf=cdf);
 print(csR);
 
 
@@ -21,7 +20,7 @@ print(csR);
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 acc <- AllelicCrosstalkCalibration(csR);
 print(acc);
-csC <- process(acc, verbose=log);
+csC <- process(acc, verbose=verbose);
 print(csC);
 
 
@@ -29,7 +28,9 @@ print(csC);
 # Plot allele pairs before and after calibration
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 for (what in c("input", "output")) {
-  plotAllelePairs(acc, array=1, what=what, verbose=log);
+  toPNG(getFullName(acc), tags=c("allelePairs", what), aspectRatio=0.7, {
+    plotAllelePairs(acc, array=1, what=what, verbose=verbose);
+  });
 }
 
 
@@ -40,12 +41,12 @@ plm <- AvgSnpPlm(csC, mergeStrands=TRUE);
 print(plm);
 if (length(findUnitsTodo(plm)) > 0) {
   # Fit CN probes quickly (~5-10s/array + some overhead)
-  units <- fitCnProbes(plm, verbose=log);
+  units <- fitCnProbes(plm, verbose=verbose);
   str(units);
   # int [1:2377527] 401698 401699 401700 401701 401702 401703 ...
 
   # Fit remaining units, i.e. SNPs (~5-10min/array)
-  units <- fit(plm, verbose=log);
+  units <- fit(plm, verbose=verbose);
   str(units);
   # int [1:418181] 1 2 3 4 5 6 7 8 9 10 ...
 }
@@ -57,7 +58,7 @@ print(ces);
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Export (theta, beta) for all arrays
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-dsList <- exportTotalAndFracB(ces, verbose=log);
+dsList <- exportTotalAndFracB(ces, verbose=verbose);
 print(dsList);
 
 
@@ -67,7 +68,6 @@ print(dsList);
 cns <- CbsModel(dsList$total);
 print(cns);
 
-ce <- ChromosomeExplorer(cns);
-setZooms(ce, 2^(0:5));
+ce <- ChromosomeExplorer(cns, zooms=2^(0:5));
 print(ce);
-process(ce, chromosomes=c(19, 22, 23), verbose=log);
+process(ce, chromosomes=c(19, 22, 23), verbose=verbose);
